@@ -1,6 +1,6 @@
 class DataLoaderGroup():
-    def __init__(self, train_dl, valid_dl):
-        self.train_dl, self.valid_dl = train_dl, valid_dl
+    def __init__(self, train_dl, valid_dl, test_dl=None):
+        self.train_dl, self.valid_dl, self.test_dl = train_dl, valid_dl, test_dl
 
     @property
     def train_ds(self):
@@ -8,4 +8,8 @@ class DataLoaderGroup():
 
     @property
     def valid_ds(self):
-        return self.valid_dl.dataset
\ No newline at end of file
+        return self.valid_dl.dataset
+
+    @property
+    def test_ds(self):
+        return self.test_dl.dataset
